@@ -3,5 +3,5 @@ pub mod lapack;
 #[cfg(feature = "native")]
 pub mod native;
 
-pub mod choleskydec;
+mod choleskydec;
 pub use self::choleskydec::CholeskyDec;
