@@ -3,6 +3,7 @@ use crate::algebra::linear::{Matrix, Vector};
 use serde::{Deserialize, Serialize};
 use std::clone::Clone;
 
+/// Result of a Eigen decomposition
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[derive(Debug, Clone)]
 pub struct EigenDec<T>
@@ -18,18 +19,18 @@ impl<T> EigenDec<T>
         EigenDec { value, _vector: vector }
     }
 
-    pub fn value(self: Self) -> Vector<T>
+    pub fn value(self) -> Vector<T>
     {
         self.value
     }
 
-    pub fn vector(self: Self) -> Matrix<T>
+    pub fn vector(self) -> Matrix<T>
     {
         unimplemented!();
         // return self.vector;
     }
 
-    pub fn pair(self: Self) -> (Vector<T>, Matrix<T>)
+    pub fn pair(self) -> (Vector<T>, Matrix<T>)
     {
         unimplemented!();
         // return (self.value, self.vector);
