@@ -3,6 +3,7 @@ use crate::algebra::linear::Matrix;
 use serde::{Deserialize, Serialize};
 use std::clone::Clone;
 
+/// Result of a Hessenberg decomposition
 #[cfg_attr(feature = "serde", derive(Serialize, Deserialize))]
 #[derive(Debug, Clone)]
 pub struct HessenbergDec<T>
@@ -15,20 +16,20 @@ impl<T> HessenbergDec<T>
 {
     pub(super) fn new(q: Matrix<T>, h: Matrix<T>) -> HessenbergDec<T>
     {
-        return HessenbergDec { q, h };
+        HessenbergDec { q, h }
     }
 
-    pub fn q(self: Self) -> Matrix<T>
+    pub fn q(self) -> Matrix<T>
     {
         self.q
     }
 
-    pub fn h(self: Self) -> Matrix<T>
+    pub fn h(self) -> Matrix<T>
     {
         self.h
     }
 
-    pub fn qh(self: Self) -> (Matrix<T>, Matrix<T>)
+    pub fn qh(self) -> (Matrix<T>, Matrix<T>)
     {
         (self.q, self.h)
     }
