@@ -21,7 +21,7 @@ impl<T> Iterator for VectorIntoIterator<T> where T: Field + Scalar
 {
     type Item = T;
 
-    fn next(self: &mut Self) -> Option<Self::Item>
+    fn next(&mut self) -> Option<Self::Item>
     {
         self.iter.next()
     }
