@@ -16,18 +16,18 @@ use std::clone::Clone;
 /// ```math
 /// \frac{dy}{dt} = ay = f(t, y)
 /// ```
-/// The initial condition is $`y(0) = 0.5`$ and we solve it in the interval
-/// $`\lbrack 0, 2\rbrack`$ The following equation is the closed solution for
+/// The initial condition is $y(0) = 0.5$ and we solve it in the interval
+/// $\lbrack 0, 2\rbrack$ The following equation is the closed solution for
 /// this ODE:
 /// ```math
 /// y(t) = C a e^{at}
 /// ```
-/// $`C`$ is a parameter and depends on the initial condition $`y(t_{0})`$
+/// $C$ is a parameter and depends on the initial condition $y(t_{0})$
 /// ```math
 /// C = \frac{y(t_{0})}{ae^{at_{0}}}
 /// ```
 ///
-/// In this example, we set $`a=2`$
+/// In this example, we set $a=2$
 /// ```
 /// # #[macro_use]
 /// # extern crate mathru;
@@ -55,17 +55,17 @@ use std::clone::Clone;
 ///
 /// impl ExplicitODE<f64> for ExplicitODE1
 /// {
-///     fn func(self: &Self, _t: &f64, x: &Vector<f64>) -> Vector<f64>
+///     fn func(&self, _t: &f64, x: &Vector<f64>) -> Vector<f64>
 ///     {
 ///         return x * &2.0f64;
 ///     }
 ///
-///     fn time_span(self: &Self) -> (f64, f64)
+///     fn time_span(&self) -> (f64, f64)
 ///     {
 ///         return self.time_span;
 ///     }
 ///
-///     fn init_cond(self: &Self) -> Vector<f64>
+///     fn init_cond(&self) -> Vector<f64>
 ///     {
 ///         return self.init_cond.clone();
 ///     }
@@ -126,7 +126,7 @@ impl<T> AdamsBashforth<T> where T: Real
     /// # Panic
     ///
     /// if t_span.0 > t_span.1
-    pub fn solve<F>(self: &Self, prob: &F) -> Result<(Vec<T>, Vec<Vector<T>>), ()>
+    pub fn solve<F>(&self, prob: &F) -> Result<(Vec<T>, Vec<Vector<T>>), ()>
         where F: ExplicitODE<T>
     {
         let t_span: (T, T) = prob.time_span();
