@@ -4,8 +4,8 @@ use crate::algebra::{abstr::Real, linear::Vector};
 pub trait ImplicitFixedStepSizeMethod<T>
     where T: Real
 {
-    fn do_step<F>(self: &Self, prob: &F, t_n: &T, x_n: &Vector<T>, h: &T) -> Vector<T>
+    fn do_step<F>(&self, prob: &F, t_n: &T, x_n: &Vector<T>, h: &T) -> Vector<T>
         where F: ImplicitODE<T>;
 
-    fn order(self: &Self) -> u8;
+    fn order(&self) -> u8;
 }
