@@ -37,14 +37,14 @@ impl<T> Default for Midpoint<T> where T: Real
 
 impl<T> ExplicitMethod<T> for Midpoint<T> where T: Real
 {
-    fn do_step<F>(self: &Self, prob: &F, t_n: &T, x_n: &Vector<T>, h: &T) -> Vector<T>
+    fn do_step<F>(&self, prob: &F, t_n: &T, x_n: &Vector<T>, h: &T) -> Vector<T>
         where F: ExplicitODE<T>
     {
         self.butcher.do_step(prob, t_n, x_n, h)
     }
 
     // The midpoint methods is a 2nd order method
-    fn order(self: &Self) -> u8
+    fn order(&self) -> u8
     {
         2
     }
