@@ -10,40 +10,40 @@ use crate::elementary::exponential::Exponential;
 pub trait Hyperbolic
 {
     /// Hyperbolic sine
-    fn sinh(self: Self) -> Self;
+    fn sinh(self) -> Self;
 
     /// Hyperbolic cosine
-    fn cosh(self: Self) -> Self;
+    fn cosh(self) -> Self;
 
     /// Hyperbolic tangens
-    fn tanh(self: Self) -> Self;
+    fn tanh(self) -> Self;
 
     /// Hyperbolic cotangens
-    fn coth(self: Self) -> Self;
+    fn coth(self) -> Self;
 
     /// Hyperbolic secant
-    fn sech(self: Self) -> Self;
+    fn sech(self) -> Self;
 
     /// Hyperbolic cosecant
-    fn csch(self: Self) -> Self;
+    fn csch(self) -> Self;
 
     /// Inverse hyperbolic  sine
-    fn arsinh(self: Self) -> Self;
+    fn arsinh(self) -> Self;
 
     /// Inverse hyperbolic cosine
-    fn arcosh(self: Self) -> Self;
+    fn arcosh(self) -> Self;
 
     /// Inverse hyperbolic tangens
-    fn artanh(self: Self) -> Self;
+    fn artanh(self) -> Self;
 
     /// Inverse hyperbolic cosecant
-    fn arcoth(self: Self) -> Self;
+    fn arcoth(self) -> Self;
 
     /// Inverse hyperbolic secant
-    fn arsech(self: Self) -> Self;
+    fn arsech(self) -> Self;
 
     /// Inverse hyperbolic cosecant
-    fn arcsch(self: Self) -> Self;
+    fn arcsch(self) -> Self;
 }
 
 macro_rules! hyperbolic_impl {
@@ -51,13 +51,13 @@ macro_rules! hyperbolic_impl {
         impl Hyperbolic for $t
         {
             /// Hyperbolic sine
-            fn sinh(self: Self) -> Self
+            fn sinh(self) -> Self
             {
                 self.sinh()
             }
 
             /// Hyperbolic cosine
-            fn cosh(self: Self) -> Self
+            fn cosh(self) -> Self
             {
                 self.cosh()
             }
@@ -77,7 +77,7 @@ macro_rules! hyperbolic_impl {
             ///
             /// let f: f64 = x.tanh();
             /// ```
-            fn tanh(self: Self) -> Self
+            fn tanh(self) -> Self
             {
                 self.tanh()
             }
@@ -101,7 +101,7 @@ macro_rules! hyperbolic_impl {
             ///
             /// let f: f64 = x.coth();
             /// ```
-            fn coth(self: Self) -> Self
+            fn coth(self) -> Self
             {
                 if self == 0.0
                 {
@@ -126,7 +126,7 @@ macro_rules! hyperbolic_impl {
             ///
             /// let f: f64 = x.sech();
             /// ```
-            fn sech(self: Self) -> Self
+            fn sech(self) -> Self
             {
                 1.0 / self.cosh()
             }
@@ -151,7 +151,7 @@ macro_rules! hyperbolic_impl {
             ///
             /// let f: f64 = x.csch();
             /// ```
-            fn csch(self: Self) -> Self
+            fn csch(self) -> Self
             {
                 if self == 0.0
                 {
@@ -161,19 +161,19 @@ macro_rules! hyperbolic_impl {
             }
 
             /// Hyperbolic inverse sine
-            fn arsinh(self: Self) -> Self
+            fn arsinh(self) -> Self
             {
                 self.asinh()
             }
 
             /// Hyperbolic inverse cosine
-            fn arcosh(self: Self) -> Self
+            fn arcosh(self) -> Self
             {
                 self.acosh()
             }
 
             /// Hyperbolic inverse tangens
-            fn artanh(self: Self) -> Self
+            fn artanh(self) -> Self
             {
                 if -1.0 >= self || self >= 1.0
                 {
@@ -204,9 +204,9 @@ macro_rules! hyperbolic_impl {
             /// let x: f64 = 2.0_f64;
             /// let f: f64 = x.arcoth();
             /// ```
-            fn arcoth(self: Self) -> Self
+            fn arcoth(self) -> Self
             {
-                if -1.0 <= self && self <= 1.0
+                if (-1.0..=1.0).contains(&self)
                 {
                     panic!();
                 }
@@ -233,7 +233,7 @@ macro_rules! hyperbolic_impl {
             /// let f: f64 = x.arsech();
             /// let g: f64 = (1.0 / x).arcosh();
             /// ```
-            fn arsech(self: Self) -> Self
+            fn arsech(self) -> Self
             {
                 if 0.0 >= self || self > 1.0
                 {
@@ -264,7 +264,7 @@ macro_rules! hyperbolic_impl {
             /// let x: f64 = 2.0_f64;
             /// let f: f64 = x.arcsch();
             /// ```
-            fn arcsch(self: Self) -> Self
+            fn arcsch(self) -> Self
             {
                 (1.0 / self).arsinh()
             }
@@ -281,37 +281,37 @@ impl<T> Hyperbolic for Complex<T>
     where T: Real
 {
     /// Hyperbolic sine
-    fn sinh(self: Self) -> Self
+    fn sinh(self) -> Self
     {
         Complex::new(T::zero(), -T::one()) * Complex::new(-self.im, self.re).sin()
     }
 
     /// Hyperbolic cosine
-    fn cosh(self: Self) -> Self
+    fn cosh(self) -> Self
     {
         Complex::new(-self.im, self.re).cos()
     }
 
     /// Hyperbolic tangens
-    fn tanh(self: Self) -> Self
+    fn tanh(self) -> Self
     {
         self.sinh() / self.cosh()
     }
 
     /// Hyperbolic cotangens
-    fn coth(self: Self) -> Self
+    fn coth(self) -> Self
     {
         self.cosh() / self.sinh()
     }
 
     /// Hyperbolic secant
-    fn sech(self: Self) -> Self
+    fn sech(self) -> Self
     {
         Complex::new(-self.im, self.re).sec()
     }
 
     /// Hyperbolic cosecant
-    fn csch(self: Self) -> Self
+    fn csch(self) -> Self
     {
         Complex::new(T::zero(), -T::one()) * Complex::new(-self.im, self.re).csc()
     }
@@ -321,7 +321,7 @@ impl<T> Hyperbolic for Complex<T>
     /// # Arguments
     ///
     /// # Panics
-    fn arsinh(self: Self) -> Self
+    fn arsinh(self) -> Self
     {
         let p: Complex<T> = Complex::new(T::one() / (T::one() + T::one()), T::zero());
         (self + (self * self + Complex::one()).pow(p)).ln()
@@ -332,7 +332,7 @@ impl<T> Hyperbolic for Complex<T>
     /// # Argument
     ///
     /// # Panics
-    fn arcosh(self: Self) -> Self
+    fn arcosh(self) -> Self
     {
         let p: Complex<T> = Complex::new(T::one() / (T::one() + T::one()), T::zero());
         (self + (self * self - Complex::one()).pow(p)).ln()
@@ -343,7 +343,7 @@ impl<T> Hyperbolic for Complex<T>
     /// # Arguments
     ///
     /// # Panics
-    fn artanh(self: Self) -> Self
+    fn artanh(self) -> Self
     {
         let f: Complex<T> = Complex::new(T::one() / (T::one() + T::one()), T::zero());
         ((Complex::one() + self) / (Complex::one() - self)).ln() * f
@@ -355,20 +355,20 @@ impl<T> Hyperbolic for Complex<T>
     ///
     ///
     /// # Panics
-    fn arcoth(self: Self) -> Self
+    fn arcoth(self) -> Self
     {
         let f: Complex<T> = Complex::new(T::one() / (T::one() + T::one()), T::zero());
         ((self + Complex::one()) / (self - Complex::one())).ln() * f
     }
 
     /// Hyperbolic inverse secant
-    fn arsech(self: Self) -> Self
+    fn arsech(self) -> Self
     {
         (Complex::one() / self).arcosh()
     }
 
     // Hyperbolic inverse cosecant
-    fn arcsch(self: Self) -> Self
+    fn arcsch(self) -> Self
     {
         (Complex::one() / self).arsinh()
     }
@@ -381,37 +381,37 @@ impl<T> Hyperbolic for Complex<T>
           // Complex<T>: Lapack + Blas
 {
     /// Hyperbolic sine
-    fn sinh(self: Self) -> Self
+    fn sinh(self) -> Self
     {
         Complex::new(T::zero(), -T::one()) * Complex::new(-self.im, self.re).sin()
     }
 
     /// Hyperbolic cosine
-    fn cosh(self: Self) -> Self
+    fn cosh(self) -> Self
     {
         Complex::new(-self.im, self.re).cos()
     }
 
     /// Hyperbolic tangens
-    fn tanh(self: Self) -> Self
+    fn tanh(self) -> Self
     {
         self.sinh() / self.cosh()
     }
 
     /// Hyperbolic cotangens
-    fn coth(self: Self) -> Self
+    fn coth(self) -> Self
     {
         self.cosh() / self.sinh()
     }
 
     /// Hyperbolic secant
-    fn sech(self: Self) -> Self
+    fn sech(self) -> Self
     {
         Complex::new(-self.im, self.re).sec()
     }
 
     /// Hyperbolic cosecant
-    fn csch(self: Self) -> Self
+    fn csch(self) -> Self
     {
         Complex::new(T::zero(), -T::one()) * Complex::new(-self.im, self.re).csc()
     }
@@ -421,7 +421,7 @@ impl<T> Hyperbolic for Complex<T>
     /// # Arguments
     ///
     /// # Panics
-    fn arsinh(self: Self) -> Self
+    fn arsinh(self) -> Self
     {
         let p: Complex<T> = Complex::new(T::one() / (T::one() + T::one()), T::zero());
         (self + (self * self + Complex::one()).pow(p)).ln()
@@ -432,7 +432,7 @@ impl<T> Hyperbolic for Complex<T>
     /// # Argument
     ///
     /// # Panics
-    fn arcosh(self: Self) -> Self
+    fn arcosh(self) -> Self
     {
         let p: Complex<T> = Complex::new(T::one() / (T::one() + T::one()), T::zero());
         (self + (self * self - Complex::one()).pow(p)).ln()
@@ -443,7 +443,7 @@ impl<T> Hyperbolic for Complex<T>
     /// # Arguments
     ///
     /// # Panics
-    fn artanh(self: Self) -> Self
+    fn artanh(self) -> Self
     {
         let f: Complex<T> = Complex::new(T::one() / (T::one() + T::one()), T::zero());
         ((Complex::one() + self) / (Complex::one() - self)).ln() * f
@@ -455,20 +455,20 @@ impl<T> Hyperbolic for Complex<T>
     ///
     ///
     /// # Panics
-    fn arcoth(self: Self) -> Self
+    fn arcoth(self) -> Self
     {
         let f: Complex<T> = Complex::new(T::one() / (T::one() + T::one()), T::zero());
         ((self + Complex::one()) / (self - Complex::one())).ln() * f
     }
 
     /// Hyperbolic inverse secant
-    fn arsech(self: Self) -> Self
+    fn arsech(self) -> Self
     {
         (Complex::one() / self).arcosh()
     }
 
     // Hyperbolic inverse cosecant
-    fn arcsch(self: Self) -> Self
+    fn arcsch(self) -> Self
     {
         (Complex::one() / self).arsinh()
     }
