@@ -62,7 +62,7 @@ impl<T> Continuous<T> for Beta<T> where T: Real + beta::Beta
     /// let x: f64 = 0.5;
     /// let p: f64 = distrib.pdf(x);
     /// ```
-    fn pdf(self: &Self, x: T) -> T
+    fn pdf(&self, x: T) -> T
     {
         if x < T::zero()
         {
@@ -90,13 +90,13 @@ impl<T> Continuous<T> for Beta<T> where T: Real + beta::Beta
     /// let x: f64 = 0.4;
     /// let p: f64 = distrib.cdf(x);
     /// ```
-    fn cdf(self: &Self, x: T) -> T
+    fn cdf(&self, x: T) -> T
     {
         beta::beta_inc_reg(x, self.p, self.q)
     }
 
     /// Quantile function of inverse cdf
-    fn quantile(self: &Self, _p: T) -> T
+    fn quantile(&self, _p: T) -> T
     {
         unimplemented!();
     }
@@ -111,7 +111,7 @@ impl<T> Continuous<T> for Beta<T> where T: Real + beta::Beta
     /// let distrib: Beta<f64> = Beta::new(0.2, 0.3);
     /// let mean: f64 = distrib.mean();
     /// ```
-    fn mean(self: &Self) -> T
+    fn mean(&self) -> T
     {
         self.p / (self.p + self.q)
     }
@@ -126,7 +126,7 @@ impl<T> Continuous<T> for Beta<T> where T: Real + beta::Beta
     /// let distrib: Beta<f64> = Beta::new(0.2, 0.3);
     /// let var: f64 = distrib.variance();
     /// ```
-    fn variance(self: &Self) -> T
+    fn variance(&self) -> T
     {
         self.p * self.q / ((self.p + self.q + T::one()) * (self.p + self.q).pow(T::from_f64(2.0)))
     }
@@ -141,18 +141,18 @@ impl<T> Continuous<T> for Beta<T> where T: Real + beta::Beta
     /// let distrib: Beta<f64> = Beta::new(0.2, 0.3);
     /// let skewness: f64 = distrib.skewness();
     /// ```
-    fn skewness(self: &Self) -> T
+    fn skewness(&self) -> T
     {
         T::from_f64(2.0) * (self.q - self.p) * (self.p + self.q + T::one()).sqrt()
                / ((self.p + self.q + T::from_f64(2.0)) * (self.q * self.p).sqrt())
     }
 
-    fn median(self: &Self) -> T
+    fn median(&self) -> T
     {
         unimplemented!();
     }
 
-    fn entropy(self: &Self) -> T
+    fn entropy(&self) -> T
     {
         unimplemented!();
     }
