@@ -49,7 +49,7 @@ impl<T> Uniform<T> where T: Real
 
 impl<T> Distribution<T> for Uniform<T> where T: Real
 {
-    fn random(self: &Self) -> T
+    fn random(&self) -> T
     {
         let mut rng: ThreadRng = rand::thread_rng();
         T::from_f64(rng.gen_range(self.a.to_f64()..self.b.to_f64()))
@@ -73,7 +73,7 @@ impl<T> Continuous<T> for Uniform<T> where T: Real
     /// let x: f64 = 5.0;
     /// let p: f64 = distrib.pdf(x);
     /// ```
-    fn pdf(self: &Self, x: T) -> T
+    fn pdf(&self, x: T) -> T
     {
         if self.a <= x && x <= self.b
         {
@@ -100,7 +100,7 @@ impl<T> Continuous<T> for Uniform<T> where T: Real
     /// let x: f64 = 0.3;
     /// let p: f64 = distrib.cdf(x);
     /// ```
-    fn cdf(self: &Self, x: T) -> T
+    fn cdf(&self, x: T) -> T
     {
         if x < self.a
         {
@@ -134,7 +134,7 @@ impl<T> Continuous<T> for Uniform<T> where T: Real
     /// let q: f64 = 0.3;
     /// let x: f64 = distrib.quantile(q);
     /// ```
-    fn quantile(self: &Self, q: T) -> T
+    fn quantile(&self, q: T) -> T
     {
         if q > T::one() || q < T::zero()
         {
@@ -158,7 +158,7 @@ impl<T> Continuous<T> for Uniform<T> where T: Real
     /// let mean: f64 = distrib.mean();
     /// assert_eq!((a + b) / 2.0, mean);
     /// ```
-    fn mean(self: &Self) -> T
+    fn mean(&self) -> T
     {
         (self.a + self.b) / T::from_f64(2.0)
     }
@@ -173,7 +173,7 @@ impl<T> Continuous<T> for Uniform<T> where T: Real
     /// let distrib: Uniform<f64> = Uniform::new(0.2, 0.5);
     /// let var: f64 = distrib.variance();
     /// ```
-    fn variance(self: &Self) -> T
+    fn variance(&self) -> T
     {
         (self.b - self.a) * (self.b - self.a) / T::from_f64(12.0)
     }
@@ -189,7 +189,7 @@ impl<T> Continuous<T> for Uniform<T> where T: Real
     /// let skewness: f64 = distrib.skewness();
     /// assert_eq!(0.0, skewness);
     /// ```
-    fn skewness(self: &Self) -> T
+    fn skewness(&self) -> T
     {
         T::zero()
     }
@@ -208,7 +208,7 @@ impl<T> Continuous<T> for Uniform<T> where T: Real
     /// let median: f64 = distrib.median();
     /// assert_eq!((a + b) / 2.0, median);
     /// ```
-    fn median(self: &Self) -> T
+    fn median(&self) -> T
     {
         self.mean()
     }
@@ -227,7 +227,7 @@ impl<T> Continuous<T> for Uniform<T> where T: Real
     /// let entropy: f64 = distrib.entropy();
     /// assert_eq!((b - a).ln(), entropy);
     /// ```
-    fn entropy(self: &Self) -> T
+    fn entropy(&self) -> T
     {
         (self.b - self.a).ln()
     }
